# -*- coding: utf-8 -*-
from django.contrib import admin
from django.utils.translation import ugettext_lazy as _


from jmb.core.admin.options import OrderedModelAdmin, ExtendibleModelAdmin
from jmb.core.forms.models import AdminModelForm
from jmb.video.models import AreaVideo,Video


###################################
## ADMIN                          #
###################################

class VideoAdminForm(AdminModelForm):
    class Meta:
        model = Video

class VideoAdmin(ExtendibleModelAdmin, OrderedModelAdmin):
    list_display = ('get_status_icon', 'ordering','titolo','area','file','get_edit_icon', 'get_delete_icon')
    list_display_links = ('get_edit_icon',)
    prepopulated_fields = {"slug": ("titolo",)}
    model = Video
    save_on_top = True
    search_fields = ("status", "titolo",)
    date_hierarchy = "date_create"
    list_per_page = 20
    ordering = ("ordering", "titolo",)
    form = VideoAdminForm
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields' : ('ordering',),
            'classes': ('collapse',)
        }),
        (_('Status'), {
            'fields': ('status',),
        }),
        (_("Publication datetime"),{
            'fields':('pub_date_begin','pub_date_end'),
            'classes': ('collapse',),
        }),
        (None, {'fields': (
            'area','titolo','slug',
            'sottotitolo', 'descrizione', 'thumb',
            'file', 'autoencode', 'embed_code',
        )}),
        (_("SEO settings"),{
            'fields':('page_title','meta_description','meta_keywords',),
            'classes': ('collapse',),
        }),
    )

class AreaVideoAdmin(ExtendibleModelAdmin):
    prepopulated_fields = {"slug": ("nome",)}
    list_display = (
        'get_status_icon','ordering','nome','slug',
        'get_edit_icon', 'get_delete_icon'
    )
    list_display_links = ('get_edit_icon',)
    fieldsets = (
        (_('logs admin'), {
            'fields': ('creator', 'date_create', 'last_modifier', 'date_last_modify',),
            'classes': ('collapse',)
        }),
        (_("Ordering"), {
            'fields' : ('ordering',),
            'classes': ('collapse',)
        }),
        (_('Status'), {
            'fields': ('status',),
        }),
        (None, {'fields': ('nome', 'slug',)}),
    )
    save_on_top = True

admin.site.register(AreaVideo, AreaVideoAdmin)
admin.site.register(Video, VideoAdmin)