# -*- coding: utf-8 -*-
from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _

from cms.models.pluginmodel import CMSPlugin


###################################
## CMS MODELS                    ##
###################################

class VideoSettings(CMSPlugin):

    area_slugs_included = models.SlugField(
        _("Area slugs included"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Including video area slug(s), separated by ','")
    )
    slugs_included = models.SlugField(
        _("Slugs included"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Including video slug(s), separated by ','")
    )
    area_slugs_excluded = models.SlugField(
        _("Area slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding video area slug(s), separated by ','")
    )
    slugs_excluded = models.CharField(
        _("Video slugs excluded"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Excluding video slug(s), separated by ','")
    );

    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=100,
        default='ordering, titolo'
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.VIDEO_CMSPLUGIN_VIDEOSETTINGS_TEMPLATES,
        default="cms_plugins/video/video_list.html",
        #editable=len(settings.VIDEO_CMSPLUGIN_VIDEOSETTINGS_TEMPLATES)>1
    )


    def __unicode__(self):
        if self.slugs_included:
            return self.slugs_included
        if self.area_slugs_included:
            return self.area_slugs_included
        return self.template_name

    class Meta:
        app_label = "video"



class LatestVideoSettings(CMSPlugin):

    area_slugs_included = models.SlugField(
        _("Area slugs included"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Including video area slug(s), separated by ','")
    )
    slugs_included = models.SlugField(
        _("Slugs included"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Including video slug(s), separated by ','")
    )
    area_slugs_excluded = models.SlugField(
        _("Area slugs excluded"),
        max_length=100,
        blank=True,
        help_text=_("(Optional) Excluding video area slug(s), separated by ','")
    )
    slugs_excluded = models.CharField(
        _("Video slugs excluded"),
        max_length=150,
        blank=True,
        help_text=_("(Optional) Excluding video slug(s), separated by ','")
    );

    objects_per_page = models.IntegerField(
        _("Items per page"),
        default=10,
        help_text=_("Number of video showed")
    )
    ordering = models.CharField(
        _("Ordering"),
        max_length=100,
        default='-date_last_modify, ordering, titolo'
    )
    autoplay_main_video = models.BooleanField(
        _("Autoplay main video"),
        default=False
    )
    template_name = models.CharField(
        max_length=100,
        choices=settings.VIDEO_CMSPLUGIN_LATESTVIDEOSETTINGS_TEMPLATES,
        default="/video/cms_plugins/latest_video.html",
       # editable=len(settings.VIDEO_CMSPLUGIN_LATESTVIDEOSETTINGS_TEMPLATES)>1
    )

    def __unicode__(self):
        if self.slugs_included:
            return self.slugs_included
        if self.area_slugs_included:
            return self.area_slugs_included
        return self.template_name

    class Meta:
        app_label = "video"