from django.core.paginator import Paginator
from django.utils.translation import ugettext as _

from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from jmb.video.models import Video, AreaVideo
from jmb.video.cms.models import VideoSettings, LatestVideoSettings





###################################
## CMS PLUGINS                    #
###################################

class VideoPlugin(CMSPluginBase):
    model = VideoSettings
    name = _("Video List")
    module = _("Video")


    def render(self, context, instance, placeholder):
        page = 1
        self.render_template = instance.template_name
        ordering = instance.ordering.lower().replace(" ","").split(",")

        objects = Video.objects.filter(status=1)

        if instance.area_slugs_included:
            area_slugs = instance.area_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(area__slug__in = area_slugs)
        if instance.slugs_included:
            slugs = instance.slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(categories__slug__in = area_slugs)
        if instance.area_slugs_excluded:
            excluded_area_slugs = instance.area_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(area__slug__in = excluded_area_slugs)
        if instance.slugs_excluded:
            exclusion_slugs = instance.slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = exclusion_slugs)

        objects = objects.order_by(*ordering)
        paginator = Paginator(objects, instance.objects_per_page)

        objects = paginator.page(page)

        context.update({
            'objects': objects,
            'instance': instance,
            'placeholder': placeholder,
            })
        return context

plugin_pool.register_plugin(VideoPlugin)




class LatestVideoPlugin(CMSPluginBase):
    model = LatestVideoSettings
    name = _("Latest Video")
    module = _("Video")

    def render(self, context, instance, placeholder):
        self.render_template = instance.template_name
        page = 1
        ordering = instance.ordering.lower().replace(" ","").split(",")

        objects = Video.objects.filter(status=1)
        if instance.area_slugs_included:
            area_slugs = instance.area_slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(area__slug__in = area_slugs)
        if instance.slugs_included:
            slugs = instance.slugs_included.lower().replace(" ","").split(",")
            objects = objects.filter(categories__slug__in = area_slugs)
        if instance.area_slugs_excluded:
            excluded_area_slugs = instance.area_slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(area__slug__in = excluded_area_slugs)
        if instance.slugs_excluded:
            exclusion_slugs = instance.slugs_excluded.lower().replace(" ","").split(",")
            objects = objects.exclude(slug__in = exclusion_slugs)

        objects = objects.order_by(*ordering)

        request = context['request']
        slug = None
        if request.GET:
            if 'slug' in request.GET:
                slug = request.GET['slug']

        selected = None
        if objects:
            if slug:
                selected = objects.get(slug=slug)
            else:
                selected = objects[0]

        paginator = Paginator(objects, instance.objects_per_page)
        objects = paginator.page(page)

        context.update({
            'selected': selected,
            'objects': objects,
            'instance':instance,
            'placeholder':placeholder,
        })
        return context

plugin_pool.register_plugin(LatestVideoPlugin)


