# -*- coding: utf-8 -*-

import os
import shlex
import subprocess
import datetime

from django.core.files import File
from django.db import models
from django.conf import settings
from django.utils.translation import ugettext_lazy as _
#from django_extensions.db.fields import AutoSlugField

from jmb.core.db.models import DateModel, UserModel, StatusModel, OrderedModel, SEOModel
from jmb.core.db.fields import HTMLFieldTinyMCE

###################################
## MODELS                         #
###################################
class AreaVideo(DateModel, UserModel, StatusModel, OrderedModel):
    """
    Un contenitore di video.
    """
    numero_video_mostrati = models.PositiveIntegerField(
        _("Numero video mostrati"),
        default=0
    )
    nome = models.CharField(
        _("Nome"),
        max_length=64
    )
    slug = models.SlugField(
        _('Slug'),
        unique=True
    )

    def get_video(self):
        if Video.objects.filter(area__exact=self).count() > self.numero_video_mostrati:
            return Video.objects.filter(area__exact=self)[0:self.numero_video_mostrati]
        else:
            return Video.objects.filter(area__exact=self)

    def __unicode__(self):
        return "%s - %s" % (self.ordering, self.nome)

    class Meta:
        verbose_name = _("Area Video")
        verbose_name_plural = _('Aree Video')


class Video(OrderedModel, DateModel, UserModel, StatusModel, SEOModel):
    """
    Un video. Nel template se il campo file è vuoto renderizzare il campo embed.
    """
    titolo = models.CharField(
        _("Title"),
        max_length=128
    )
    slug = models.SlugField(
        _('Slug'),
        max_length=128,
        unique=True,
        default=datetime.datetime.now
    )
    sottotitolo = models.CharField(
        _("Subtitle"),
        max_length=256
    )
    descrizione = HTMLFieldTinyMCE(
        _("Description"),
        blank=True, null=True,
    )
    thumb = models.ImageField(
        _("Thumb"),
        upload_to="video",
        blank=True, null=True
    )
    file = models.FileField(
        _("File"),
        upload_to="video",
        blank=True, null=True
    )
    autoplay = models.BooleanField(
        _("Autoplay"),
        default=False
    )
    pub_date_begin = models.DateTimeField(
        blank=True,
        null=True,
        verbose_name=_('Publication date begin'),
        help_text=_('Video publication start datetime'),
    )
    pub_date_end = models.DateTimeField(
        blank=True,
        null=True,
        verbose_name=_('Publication date end'),
        help_text=_('Video publication end datetime'),
    )
    likes = models.PositiveIntegerField(
        _("Likes"),
        default=0
    )
    dislikes = models.PositiveIntegerField(
        _("Dislikes"),
        default=0
    )
    visualizzazioni = models.PositiveIntegerField(
        _("Visualizzazioni"),
        default=0
    )
    embed_code = models.TextField(
        blank=True, null=True
    )
    autoencode = models.BooleanField(
        default=True)

    area = models.ForeignKey(
        AreaVideo,
        null=True, blank=True,
        related_name="video_area",
        verbose_name=_("Area video")
    )

    class Meta:
        ordering = ('ordering',)
        verbose_name = _('Video')
        verbose_name_plural = _('Video')


    def __unicode__(self):
        return self.titolo

    def save(self, *args, **kwargs):
        # se è un nuovo video e non ho specificato un ordinale lo setto io
        # come +10 rispetto al più grande per quell'area.
        if self.pk == None and self.ordering == 0:
            try:
                qs_max_ordering = Video.objects.filter(
                    area_video__exact=self.area_video).order_by('-ordering')
                max_ordering = qs_max_ordering[0].ordering
                self.ordering = max_ordering + 10
            except:
                pass

        super(Video, self).save(*args, **kwargs)

        if self.file:
            if self.file.name.find('.flv') == -1 and self.autoencode:
                command_line = "ffmpeg -i %s -b 600k -r 30 -ab 128k -ar 44100 -s 390x294 -ac 2 -y /tmp/output.flv" % str(self.file.path)
                splitted_command_line = shlex.split(command_line)
                retcode = subprocess.call(splitted_command_line)
                temp_file = open("/tmp/output.flv")
                try:
                    filenamepre = self.file.name.split('.')[0]
                except:
                    filenamepre = self.file.name
                self.file.save("%s.flv" % filenamepre, File(temp_file))
                os.remove('/tmp/output.flv')


    def like(self):
        self.likes += 1
        self.save()

    def dislike(self):
        self.dislikes += 1
        self.save()

    def see(self):
        self.visualizzazioni += 1
        self.save()

    class Meta(object):
        verbose_name = _('Video')
        verbose_name_plural = _('Videos')

    def __unicode__(self):
        return self.titolo[:15]


#    def get_users(self):
#        users = self.users.all().order_by('username')
#        if users:
#            return u', '.join([user.username for user in users])
#        else:
#            return _(u'All')

    def get_areas(self):
        if self.area:
            self.area.nome
        else:
            return _(u'--')
    get_areas.short_description = _('Area')


    def get_short_description(self):
        return self.short_description or "%s ....." % self.text[:100]


    def get_filename_uno(self):
        return os.path.basename(self.file.name)

#import cms stuffs
if settings.CMS_ENABLED:
    import jmb.video.cms.plugins
    import jmb.video.cms.app